var locale = {
    "Add symbol": "Lägg till symbol",
    "Allow scroll wheel zoom?": "Allow scroll wheel zoom?",
    "Automatic": "Automatisk",
    "Ball": "Knappnål",
    "Cancel": "Avbryt",
    "Caption": "Caption",
    "Change symbol": "Ändra symbol",
    "Choose the data format": "Välj dataformat",
    "Choose the layer of the feature": "Välj lager för objektet",
    "Circle": "Cirkel",
    "Clustered": "Kluster",
    "Data browser": "Data browser",
    "Default": "Förvalt värde",
    "Default zoom level": "Förvald zoomnivå",
    "Default: name": "Namn förvalt",
    "Display label": "Visa etikett",
    "Display the control to open OpenStreetMap editor": "Visa knapp för att öppna OpenStreetMap redigerare",
    "Display the data layers control": "Visa verktyg för datalager",
    "Display the embed control": "Visa verktyg för att bädda in och dela",
    "Display the fullscreen control": "Visa verktyg för fullskärm",
    "Display the locate control": "Visa lokaliseringsverktyg",
    "Display the measure control": "Visa mätverktyg",
    "Display the search control": "Visa sökverktyg",
    "Display the tile layers control": "Visa verktyg för tiles (bakgrundslager)",
    "Display the zoom control": "Visa zoomverktyg",
    "Do you want to display a caption bar?": "Do you want to display a caption bar?",
    "Do you want to display a minimap?": "Vill du visa en minikarta?",
    "Do you want to display a panel on load?": "Do you want to display a panel on load?",
    "Do you want to display popup footer?": "Do you want to display popup footer?",
    "Do you want to display the scale control?": "Vill du visa verktyget för skala?",
    "Do you want to display the «more» control?": "Do you want to display the «more» control?",
    "Drop": "Dropp-nål",
    "GeoRSS (only link)": "GeoRSS (only link)",
    "GeoRSS (title + image)": "GeoRSS (title + image)",
    "Heatmap": "Värmekarta",
    "Icon shape": "Ikonform",
    "Icon symbol": "Ikonsymbol",
    "Inherit": "Ärv",
    "Label direction": "Riktning för etikett",
    "Label key": "Label key",
    "Labels are clickable": "Klickbara etiketter",
    "None": "Ingen",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "Popup content template",
    "Set symbol": "Välj symbol",
    "Side panel": "Sidopanel",
    "Simplify": "Förenkla",
    "Symbol or url": "Symbol or url",
    "Table": "Tabell",
    "always": "alltid",
    "clear": "rensa",
    "collapsed": "minimerad",
    "color": "färg",
    "dash array": "dash array",
    "define": "definiera",
    "description": "beskrivning",
    "expanded": "utökad",
    "fill": "fyll",
    "fill color": "fyllnadsfärg",
    "fill opacity": "fill opacity",
    "hidden": "hidden",
    "iframe": "ram",
    "inherit": "ärv",
    "name": "namn",
    "never": "aldrig",
    "new window": "nytt fönster",
    "no": "nej",
    "on hover": "vid hovring",
    "opacity": "opacity",
    "parent window": "parent window",
    "stroke": "streck",
    "weight": "tjocklek",
    "yes": "ja",
    "{delay} seconds": "{delay} sekunder",
    "# one hash for main heading": "# en fyrkant för huvudrubrik",
    "## two hashes for second heading": "## två fyrkanter för andra rubrik",
    "### three hashes for third heading": "### tre fyrkanter för tredje rubrik",
    "**double star for bold**": "**dubbla stjärntecken för fetstil**",
    "*simple star for italic*": "*enkel stjärna för kursiv stil*",
    "--- for an horizontal rule": "--- för ett vågrätt streck",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "En kommaseparerad lista med nummer som definierar mönstret för den streckade linjen. Ex: \"5, 10, 15\"",
    "About": "Om kartan",
    "Action not allowed :(": "Åtgärden är inte tillåten :(",
    "Activate slideshow mode": "Aktivera bildspelsläge",
    "Add a layer": "Lägg till lager",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Add a new property",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Avancerade åtgärder",
    "Advanced properties": "Avancerade egenskaper",
    "Advanced transition": "Avancerad övergång",
    "All properties are imported.": "Alla egenskaper har importerats.",
    "Allow interactions": "Tillåt interaktion",
    "An error occured": "Ett fel inträffade",
    "Are you sure you want to cancel your changes?": "Är du säker på att du vill avbryta dina ändringar?",
    "Are you sure you want to clone this map and all its datalayers?": "Är du säker på att du vill skapa en kopia av kartan och alla datalager?",
    "Are you sure you want to delete the feature?": "Är du säker på att du vill radera objektet?",
    "Are you sure you want to delete this layer?": "Är du säker på att du vill radera lagret?",
    "Are you sure you want to delete this map?": "Är du säker på att du vill radera denna karta?",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Är du säker på att du vill återställa till den här versionen?",
    "Attach the map to my account": "Koppla kartan till mitt konto",
    "Auto": "Automatiskt",
    "Autostart when map is loaded": "Starta automatiskt när kartan lästs in.",
    "Bring feature to center": "Centrera objektet",
    "Browse data": "Browse data",
    "Cancel edits": "Avbryt ändringar",
    "Center map on your location": "Centrera kartan till din plats",
    "Change map background": "Ändra kartbakgrund",
    "Change tilelayers": "Ändra tile-lager",
    "Choose a preset": "Välj förinställning",
    "Choose the format of the data to import": "Välj dataformat för importen",
    "Choose the layer to import in": "Välj lager att importera till",
    "Click last point to finish shape": "Klicka på sista punkten för att slutföra formen",
    "Click to add a marker": "Klicka för att lägga till en markör",
    "Click to continue drawing": "Klicka för att fortsätta rita",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Klicka för att börja rita en linje",
    "Click to start drawing a polygon": "Klicka för att börja rita en polygon",
    "Clone": "Clone",
    "Clone of {name}": "Kopia av {name}",
    "Clone this feature": "Kopiera detta objekt",
    "Clone this map": "Skapa en kopia av kartan",
    "Close": "Stäng",
    "Clustering radius": "Klusterradie",
    "Comma separated list of properties to use when filtering features": "Kommaseparerad lista med egenskaper, som används vid filtrering av objekt",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Continue line",
    "Continue line (Ctrl+Click)": "Continue line (Ctrl+Click)",
    "Coordinates": "Koordinater",
    "Credits": "Credits",
    "Current view instead of default map view?": "Nuvarande vy istället för den förinställda vyn?",
    "Custom background": "Anpassad bakgrund",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Förinställda alternativ för interaktion",
    "Default properties": "Default properties",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Radera",
    "Delete all layers": "Radera alla lager",
    "Delete layer": "Radera lager",
    "Delete this feature": "Radera objektet",
    "Delete this property on all the features": "Ta bort denna egenskap från alla objekt",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Directions from here": "Vägbeskrivning härifrån",
    "Disable editing": "Disable editing",
    "Display measure": "Display measure",
    "Display on load": "Display on load",
    "Download": "Ladda ned",
    "Download data": "Ladda ned data",
    "Drag to reorder": "Dra för att sortera om",
    "Draw a line": "Rita en linje",
    "Draw a marker": "Rita en markör",
    "Draw a polygon": "Rita en polygon",
    "Draw a polyline": "Rita en multilinje",
    "Dynamic": "Dynamisk",
    "Dynamic properties": "Dynamiska egenskaper",
    "Edit": "Redigera",
    "Edit feature's layer": "Redigera objektets lager",
    "Edit map properties": "Redigera kartans egenskaper",
    "Edit map settings": "Redigera kartans inställningar",
    "Edit properties in a table": "Redigera tabellegenskaper",
    "Edit this feature": "Redigera objektet",
    "Editing": "Redigerar",
    "Embed and share this map": "Bädda in och dela den här kartan",
    "Embed the map": "Bädda in kartan",
    "Empty": "Töm",
    "Enable editing": "Aktivera redigering",
    "Error in the tilelayer URL": "Fel i webbadressen för tile-lagret",
    "Error while fetching {url}": "Fel vid hämtning av {url}",
    "Exit Fullscreen": "Lämna helskärmsläge",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Filter…": "Filter…",
    "Format": "Format",
    "From zoom": "Från zoom",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Gå till «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Värmekartans radie",
    "Help": "Hjälp",
    "Hide controls": "Hide controls",
    "Home": "Hem",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe export options": "Iframe export options",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Image with custom width (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Image: {{http://image.url.com}}",
    "Import": "Import",
    "Import data": "Import data",
    "Import in a new layer": "Import in a new layer",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Include full screen link?",
    "Interaction options": "Alternativ för interaktion",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "Latitud",
    "Layer": "Layer",
    "Layer properties": "Layer properties",
    "Licence": "Licence",
    "Limit bounds": "Limit bounds",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Hyperlänk med egen text: [[http://example.com|länktext]",
    "Long credits": "Long credits",
    "Longitude": "Longitud",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Map has been saved!",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Merge lines",
    "More controls": "More controls",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "No licence has been set",
    "No results": "No results",
    "Only visible features will be downloaded.": "Only visible features will be downloaded.",
    "Open download panel": "Öppna nedladdningspanelen",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Optional. Same as color if not set.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Please be sure the licence is compliant with your use.": "Please be sure the licence is compliant with your use.",
    "Please choose a format": "Please choose a format",
    "Please enter the name of the property": "Please enter the name of the property",
    "Please enter the new name of this property": "Please enter the new name of this property",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.",
    "Problem in the response": "Servern svarade med ett fel",
    "Problem in the response format": "Problem in the response format",
    "Properties imported:": "Properties imported:",
    "Property to use for sorting features": "Property to use for sorting features",
    "Provide an URL here": "Ange en webbadress",
    "Proxy request": "Proxy request",
    "Remote data": "Fjärrdata",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Rename this property on all the features",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "Save",
    "Save anyway": "Save anyway",
    "Save current edits": "Save current edits",
    "Save this center and zoom": "Save this center and zoom",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "See all",
    "See data layers": "See data layers",
    "See full screen": "See full screen",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Short URL",
    "Short credits": "Short credits",
    "Show/hide layer": "Show/hide layer",
    "Simple link: [[http://example.com]]": "Enkel hyperlänk: [[http://example.com]]",
    "Slideshow": "Slideshow",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Start a hole here": "Start a hole here",
    "Start editing": "Start editing",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Stop editing",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "TMS format",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Text formatting",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been set.": "Zoom och centrering har satts.",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "To zoom",
    "Toggle edit mode (Shift+Click)": "Toggle edit mode (Shift+Click)",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transform to lines",
    "Transform to polygon": "Transform to polygon",
    "Type of layer": "Type of layer",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Untitled layer",
    "Untitled map": "Untitled map",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Uppdatera behörigheter och redaktörer",
    "Url": "Url",
    "Use current bounds": "Use current bounds",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "User content credits",
    "User interface options": "User interface options",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Where do we go from here?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "You have unsaved changes.": "You have unsaved changes.",
    "Zoom in": "Zoom in",
    "Zoom level for automatic zooms": "Zoomnivå för automatisk zoom",
    "Zoom out": "Zoom out",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Zoom to this feature",
    "Zoom to this place": "Zoom to this place",
    "attribution": "attribution",
    "by": "by",
    "display name": "display name",
    "height": "height",
    "licence": "licens",
    "max East": "max East",
    "max North": "max North",
    "max South": "max South",
    "max West": "max West",
    "max zoom": "max zoom",
    "min zoom": "min zoom",
    "next": "nästa",
    "previous": "föregående",
    "width": "bredd",
    "{count} errors during import: {message}": "{count} fel under importen: {message}",
    "Measure distances": "Mät avstånd",
    "NM": "M",
    "kilometers": "kilometer",
    "km": "km",
    "mi": "miles",
    "miles": "engelska mil",
    "nautical miles": "nautiska mil",
    "{area} acres": "{area} acre (ung. tunnland)",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} kvadrat-mile",
    "{area} yd&sup2;": "{area} kvadratyard",
    "{distance} NM": "{distance} M",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} engelska mil",
    "{distance} yd": "{distance} yard",
    "1 day": "1 dag",
    "1 hour": "1 timme",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Optional.": "Optional.",
    "Paste your data here": "Paste your data here",
    "Please save the map first": "Please save the map first",
    "Unable to locate you.": "Unable to locate you.",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier."
};
L.registerLocale("sv", locale);
L.setLocale("sv");