var locale = {
    "Add symbol": "Додај симбол",
    "Allow scroll wheel zoom?": "Допусти увећање зумом миша",
    "Automatic": "Аутоматско",
    "Ball": "Лопта",
    "Cancel": "Откажи",
    "Caption": "Напомена",
    "Change symbol": "Промени симбол",
    "Choose the data format": "Одабери формат датума",
    "Choose the layer of the feature": "Одабери лејер ",
    "Circle": "Круг",
    "Clustered": "Clustered",
    "Data browser": "Претражи податке",
    "Default": "Фабричка подешавања",
    "Default zoom level": "Подразумевани ниво зумирања",
    "Default: name": "Фабричко: Име",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Do you want to display a caption bar?",
    "Do you want to display a minimap?": "Желите ли приказати малу карту?",
    "Do you want to display a panel on load?": "Do you want to display a panel on load?",
    "Do you want to display popup footer?": "Желите ли приказати скочни прозор у подножју?",
    "Do you want to display the scale control?": "Do you want to display the scale control?",
    "Do you want to display the «more» control?": "Do you want to display the «more» control?",
    "Drop": "Drop",
    "GeoRSS (only link)": "GeoRSS (only link)",
    "GeoRSS (title + image)": "GeoRSS (title + image)",
    "Heatmap": "Heatmap",
    "Icon shape": "Icon shape",
    "Icon symbol": "Икона симбола",
    "Inherit": "Inherit",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "Ништа",
    "On the bottom": "На дну",
    "On the left": "На лево",
    "On the right": "На десно",
    "On the top": "На врху",
    "Popup content template": "Popup content template",
    "Set symbol": "Постави симбол",
    "Side panel": "Side panel",
    "Simplify": "Simplify",
    "Symbol or url": "Симбол или url",
    "Table": "Табела",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "боја",
    "dash array": "dash array",
    "define": "define",
    "description": "Опис",
    "expanded": "expanded",
    "fill": "испуна",
    "fill color": "боја испуне",
    "fill opacity": "прозирност испуне",
    "hidden": "сакриј",
    "iframe": "iframe",
    "inherit": "inherit",
    "name": "име",
    "never": "никад",
    "new window": "нови прозор",
    "no": "не",
    "on hover": "on hover",
    "opacity": "прозирност",
    "parent window": "parent window",
    "stroke": "линија",
    "weight": "дебљина",
    "yes": "да",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# једна тараба за главни наслов",
    "## two hashes for second heading": "## две тарабе за поднаслов",
    "### three hashes for third heading": "### три тарабе за под-поднаслова",
    "**double star for bold**": "** две звезвдице за подебљање слова**",
    "*simple star for italic*": "* једна стрелица за искошење слова*",
    "--- for an horizontal rule": "-- за хоризонталну црту",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Више о",
    "Action not allowed :(": "Акција није дозвољена :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Додај лејер",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Add a new property",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Напредне акције",
    "Advanced properties": "Напредне поставке",
    "Advanced transition": "Advanced transition",
    "All properties are imported.": "Све поставке су увезене",
    "Allow interactions": "Allow interactions",
    "An error occured": "Догодила се грешка",
    "Are you sure you want to cancel your changes?": "Да ли сте сигурне да желите да откажете промене?",
    "Are you sure you want to clone this map and all its datalayers?": "Да ли сте сигурни да желите да умножите мапу и све податке на њој?",
    "Are you sure you want to delete the feature?": "Да ли сте сигурни да желите да обришете елемент?",
    "Are you sure you want to delete this layer?": "Да ли сте сигурни да желите да обришете лејер?",
    "Are you sure you want to delete this map?": "Да ли сте сигурни да желите да обришете мапу?",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Аутоматски",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Центрирај елемент",
    "Browse data": "Претражи податке",
    "Cancel edits": "Откажи промене",
    "Center map on your location": "Центрирај мапу на основу локације",
    "Change map background": "Промени позадину карте",
    "Change tilelayers": "Промени наслов лејера",
    "Choose a preset": "Choose a preset",
    "Choose the format of the data to import": "Choose the format of the data to import",
    "Choose the layer to import in": "Одабери лејер за увоз",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Клик за додавање ознаке",
    "Click to continue drawing": "Клик да наставите са цртањем",
    "Click to edit": "Клик за уређивање",
    "Click to start drawing a line": "Клик да започнете цртање линије",
    "Click to start drawing a polygon": "Клик да започнете цртање површине",
    "Clone": "Clone",
    "Clone of {name}": "Clone of {name}",
    "Clone this feature": "Дуплирај елемент",
    "Clone this map": "Дуплирај мапу",
    "Close": "Затвори",
    "Clustering radius": "Clustering radius",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Continue line",
    "Continue line (Ctrl+Click)": "Continue line (Ctrl+Click)",
    "Coordinates": "Координате",
    "Credits": "Credits",
    "Current view instead of default map view?": "Current view instead of default map view?",
    "Custom background": "Одаберите позадину",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Фабричке вредности",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Обриши",
    "Delete all layers": "Обриши све лејере",
    "Delete layer": "Обриши лејер",
    "Delete this feature": "Обриши елемент",
    "Delete this property on all the features": "Delete this property on all the features",
    "Delete this shape": "Обриши облик",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Directions from here": "Directions from here",
    "Disable editing": "Онемогући уређивање",
    "Display measure": "Display measure",
    "Display on load": "Display on load",
    "Download": "Преузимање",
    "Download data": "Преузимање података",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Цртање линије",
    "Draw a marker": "Цртање ознаке",
    "Draw a polygon": "Цртање површине",
    "Draw a polyline": "Цртање изломљене линије",
    "Dynamic": "Dynamic",
    "Dynamic properties": "Dynamic properties",
    "Edit": "Уређивање",
    "Edit feature's layer": "Уређивање елемента одабраног лејера",
    "Edit map properties": "Уређивање мапе",
    "Edit map settings": "Уређивање више опција мапе",
    "Edit properties in a table": "Edit properties in a table",
    "Edit this feature": "Уређивање елемента",
    "Editing": "Уређивање",
    "Embed and share this map": "Embed and share this map",
    "Embed the map": "Embed the map",
    "Empty": "Empty",
    "Enable editing": "Омогући уређивање",
    "Error in the tilelayer URL": "Error in the tilelayer URL",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Умањи увећање",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Filter…": "Филтер",
    "Format": "Формат",
    "From zoom": "From zoom",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Go to «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Heatmap radius",
    "Help": "Помоћ",
    "Hide controls": "Сакриј контроле",
    "Home": "Почетна страна",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe export options": "Iframe export options",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Image with custom width (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Image: {{http://image.url.com}}",
    "Import": "Увоз",
    "Import data": "Увоз података",
    "Import in a new layer": "Увези у новом лејеру",
    "Imports all umap data, including layers and settings.": "Увези све податке из мапе, укључујући лејере и подешавања",
    "Include full screen link?": "Include full screen link?",
    "Interaction options": "Опција интеракције",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "Latitude",
    "Layer": "Лејер",
    "Layer properties": "Layer properties",
    "Licence": "Лиценца",
    "Limit bounds": "Limit bounds",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Линк са текстом [[http://example.com|text of the link]]",
    "Long credits": "Long credits",
    "Longitude": "Longitude",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Мапа је сачувана!",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Уређивачи мапе",
    "Map's owner": "Власник мапе",
    "Merge lines": "Merge lines",
    "More controls": "Више опција",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "Лиценца није постављена",
    "No results": "Нема резултата",
    "Only visible features will be downloaded.": "Само видљиви лејери ће бити скинути.",
    "Open download panel": "Отвори прозор са скидање",
    "Open link in…": "Отвори линк у...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Optional. Same as color if not set.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Please be sure the licence is compliant with your use.": "Молимо Вас уверите се да је лиценца компатибилна.",
    "Please choose a format": "Молимо Вас одаберите формат",
    "Please enter the name of the property": "Please enter the name of the property",
    "Please enter the new name of this property": "Please enter the new name of this property",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.",
    "Problem in the response": "Problem in the response",
    "Problem in the response format": "Проблем у препознавању формата",
    "Properties imported:": "Properties imported:",
    "Property to use for sorting features": "Property to use for sorting features",
    "Provide an URL here": "Упишите URL ",
    "Proxy request": "Proxy request",
    "Remote data": "Remote data",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Rename this property on all the features",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "Сачувај",
    "Save anyway": "Сачувај",
    "Save current edits": "Сачувај тренутна подешавања",
    "Save this center and zoom": "Сачувај подешавања центра и увећања",
    "Save this location as new feature": "Сачувај локацију као нови елемент",
    "Search a place name": "Претражи локацију",
    "Search location": "Претражи локацију",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "Види све",
    "See data layers": "Прикажи унесене податке",
    "See full screen": "Увећана слика",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Својства облика",
    "Short URL": "Кратки URL",
    "Short credits": "Short credits",
    "Show/hide layer": "Прикажи/сакриј лејер",
    "Simple link: [[http://example.com]]": "Simple link: [[http://example.com]]",
    "Slideshow": "Slideshow",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Start a hole here": "Start a hole here",
    "Start editing": "Започни уређивање",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Заустави уређивања",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "TMS format",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Text formatting",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been set.": "Мапа је центрирана.",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "Увећај",
    "Toggle edit mode (Shift+Click)": "Toggle edit mode (Shift+Click)",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transform to lines",
    "Transform to polygon": "Transform to polygon",
    "Type of layer": "Type of layer",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Безимени лејер",
    "Untitled map": "Безимена мапа",
    "Update permissions": "Ажурирај дозволе",
    "Update permissions and editors": "Ажурирај дозволе и уреднике",
    "Url": "URL",
    "Use current bounds": "Use current bounds",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Заслуге за садржај",
    "User interface options": "User interface options",
    "Versions": "Versions",
    "View Fullscreen": "Прикажи увећано",
    "Where do we go from here?": "Where do we go from here?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "You have unsaved changes.": "You have unsaved changes.",
    "Zoom in": "Увећај",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Умањи",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Увећај одабрано",
    "Zoom to this place": "Zoom to this place",
    "attribution": "attribution",
    "by": "by",
    "display name": "display name",
    "height": "висина",
    "licence": "лиценца",
    "max East": "max East",
    "max North": "max North",
    "max South": "max South",
    "max West": "max West",
    "max zoom": "максимално увећање",
    "min zoom": "минимално увећање",
    "next": "следеће",
    "previous": "претходно",
    "width": "дебљина",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "километри",
    "km": "km",
    "mi": "mi",
    "miles": "миље",
    "nautical miles": "наутичке миље",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 дан",
    "1 hour": "1 сат",
    "5 min": "5 минута",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Optional.": "Опционо",
    "Paste your data here": "Прикачите Ваше податке овде",
    "Please save the map first": "Молимо Вас сачувајте мапу претходно",
    "Unable to locate you.": "Unable to locate you.",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier."
};
L.registerLocale("sr", locale);
L.setLocale("sr");