var locale = {
    "Add symbol": "Legg til symbol",
    "Allow scroll wheel zoom?": "Tillat rulling med zoom-hjulet?",
    "Automatic": "Automatisk",
    "Ball": "Ball",
    "Cancel": "Avbryt",
    "Caption": "Caption",
    "Change symbol": "Endre symbol",
    "Choose the data format": "Velg dataformatet",
    "Choose the layer of the feature": "Choose the layer of the feature",
    "Circle": "Sirkel",
    "Clustered": "Clustered",
    "Data browser": "Dataleser",
    "Default": "Standard",
    "Default zoom level": "Standard zoom-nivå",
    "Default: name": "Standard: navn",
    "Display label": "Vis merkelapp",
    "Display the control to open OpenStreetMap editor": "Vis grensesnitt for å åpne OpenStreetMap-redigerer",
    "Display the data layers control": "Vis grensesnitt for datalag",
    "Display the embed control": "Vis grensesnitt for innbygging",
    "Display the fullscreen control": "Vis grensesnitt for fullskjermvisning",
    "Display the locate control": "Vis grensesnitt for lokalisering",
    "Display the measure control": "Vis grensesnitt for oppmåling",
    "Display the search control": "Vis grensesnitt for søk",
    "Display the tile layers control": "Vis grensesnitt for flis-lag",
    "Display the zoom control": "Vis grensesnitt for zoom-styring",
    "Do you want to display a caption bar?": "Do you want to display a caption bar?",
    "Do you want to display a minimap?": "Vil du vise et oversiktskart?",
    "Do you want to display a panel on load?": "Vil du vise et panel etter innlasting?",
    "Do you want to display popup footer?": "Vil du vise en popup-bunntekst?",
    "Do you want to display the scale control?": "Vil du vise grensesnitt for skalering?",
    "Do you want to display the «more» control?": "Vil du vise grensesnitt for \"mer\"?",
    "Drop": "Drop",
    "GeoRSS (only link)": "GeoRSS (bare link)",
    "GeoRSS (title + image)": "GeoRSS (tittel og bilde)",
    "Heatmap": "Varmekart",
    "Icon shape": "Ikonform",
    "Icon symbol": "Ikonsymbol",
    "Inherit": "Arve",
    "Label direction": "Merkelapp-retning",
    "Label key": "Merkelapp-nøkkel",
    "Labels are clickable": "Merkelapper er klikkbare",
    "None": "Ingen",
    "On the bottom": "På bunnen",
    "On the left": "Til venstre",
    "On the right": "Til høyre",
    "On the top": "På toppen",
    "Popup content template": "Popup content template",
    "Set symbol": "Angi symbol",
    "Side panel": "Sidepanel",
    "Simplify": "Simplifisere",
    "Symbol or url": "Symbol eller URL",
    "Table": "Tabell",
    "always": "alltid",
    "clear": "tøm",
    "collapsed": "collapsed",
    "color": "farge",
    "dash array": "dash array",
    "define": "definer",
    "description": "beskrivelse",
    "expanded": "expanded",
    "fill": "fyll",
    "fill color": "fyllfarge",
    "fill opacity": "fyllsynlighet",
    "hidden": "skjult",
    "iframe": "iframe",
    "inherit": "arve",
    "name": "navn",
    "never": "aldri",
    "new window": "nytt vindu",
    "no": "nei",
    "on hover": "når musa er over",
    "opacity": "synlighet",
    "parent window": "foreldrevindu",
    "stroke": "strøk",
    "weight": "vekt",
    "yes": "ja",
    "{delay} seconds": "{delay} sekunder",
    "# one hash for main heading": "# en emneknagg for hovedtittel",
    "## two hashes for second heading": "## to emneknagger for andre tittel",
    "### three hashes for third heading": "### tre emneknagger for tredje tittel",
    "**double star for bold**": "**dobbel stjerne for fet skrift**",
    "*simple star for italic*": "*enkel stjerne for kursiv*",
    "--- for an horizontal rule": "--- for et horisontalt skille",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "En komma-separert liste over nummer som definerer den stiplede linja. Eks.: \"5, 10, 15\".",
    "About": "Om",
    "Action not allowed :(": "Handlingen er ikke tillatt :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Legg til et lag",
    "Add a line to the current multi": "Legg en linje til gjeldende multi",
    "Add a new property": "Legg til en ny egenskap",
    "Add a polygon to the current multi": "Legg et polygon til gjeldende multi",
    "Advanced actions": "Avanserte handlinger",
    "Advanced properties": "Avanserte egenskaper",
    "Advanced transition": "Avansert overgang",
    "All properties are imported.": "Alle egenskaper er importert",
    "Allow interactions": "Tillat interaksjoner",
    "An error occured": "En feil oppsto",
    "Are you sure you want to cancel your changes?": "Er du sikker på at du vil du forkaste endringene dine?",
    "Are you sure you want to clone this map and all its datalayers?": "Er du sikker på at du vil klone dette kartet og alle tilhørende datalag?",
    "Are you sure you want to delete the feature?": "Er du sikker på at du vil slette dette objektet?",
    "Are you sure you want to delete this layer?": "Er du sikker på at du vil slette dette laget?",
    "Are you sure you want to delete this map?": "Er du sikker på at du vil slette dette kartet?",
    "Are you sure you want to delete this property on all the features?": "Er du sikker på at du vil slette denne egenskapen fra alle objektene?",
    "Are you sure you want to restore this version?": "Er du sikker på at du vil gjenopprette denne versjonen?",
    "Attach the map to my account": "Koble opp kartet til min konto",
    "Auto": "Auto",
    "Autostart when map is loaded": "Start automatisk når kartet er lastet",
    "Bring feature to center": "Før objektet til midten",
    "Browse data": "Se gjennom data",
    "Cancel edits": "Avbryt endringer",
    "Center map on your location": "Sentrer kartet på din posisjon",
    "Change map background": "Endre bakgrunnskart",
    "Change tilelayers": "Endre flislag",
    "Choose a preset": "Choose a preset",
    "Choose the format of the data to import": "Choose the format of the data to import",
    "Choose the layer to import in": "Choose the layer to import in",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Klikk for å legge til en markør",
    "Click to continue drawing": "Klikk for å fortsette å tegne",
    "Click to edit": "Klikk for å redigere",
    "Click to start drawing a line": "Klikk for å starte å tegne en linje",
    "Click to start drawing a polygon": "Klikk for å starte å tegne et polygon",
    "Clone": "Dupliser",
    "Clone of {name}": "Duplikat av {name}",
    "Clone this feature": "Dupliser dette objektet",
    "Clone this map": "Dupliser dette kartet",
    "Close": "Lukk",
    "Clustering radius": "Clustering radius",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Fortsett linje",
    "Continue line (Ctrl+Click)": "Fortsett linje (Ctrl+Klikk)",
    "Coordinates": "Koordinater",
    "Credits": "Credits",
    "Current view instead of default map view?": "Current view instead of default map view?",
    "Custom background": "Egendefinert bakgrunn",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Default properties",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Slett",
    "Delete all layers": "Slett alle lag",
    "Delete layer": "Slett lag",
    "Delete this feature": "Slett dette objektet",
    "Delete this property on all the features": "Slett denne egenskapen fra alle objekter",
    "Delete this shape": "Slett denne figuren",
    "Delete this vertex (Alt+Click)": "Slett denne noden (Alt+Klikk)",
    "Directions from here": "Navigasjon herfra",
    "Disable editing": "Deaktiver redigering",
    "Display measure": "Vis måling",
    "Display on load": "Vis ved innlasting",
    "Download": "Last ned",
    "Download data": "Last ned data",
    "Drag to reorder": "Dra for å endre rekkefølge",
    "Draw a line": "Tegn en linje",
    "Draw a marker": "Tegn en markør",
    "Draw a polygon": "Tegn et polygon",
    "Draw a polyline": "Tegn en polylinje",
    "Dynamic": "Dynamisk",
    "Dynamic properties": "Dynamiske egenskaper",
    "Edit": "Rediger",
    "Edit feature's layer": "Rediger objektets lag",
    "Edit map properties": "Rediger kartegenskaper",
    "Edit map settings": "Rediger kartinnstillinger",
    "Edit properties in a table": "Rediger egenskaper i en tabell",
    "Edit this feature": "Rediger dette objektet",
    "Editing": "Redigering",
    "Embed and share this map": "Bygg inn og del dette kartet",
    "Embed the map": "Bygg inn kartet",
    "Empty": "Tøm",
    "Enable editing": "Aktiver redigering",
    "Error in the tilelayer URL": "Feil i flislag-URLen",
    "Error while fetching {url}": "Feil under henting av {url}",
    "Exit Fullscreen": "Gå ut av fullskjerm",
    "Extract shape to separate feature": "Hent ut form til eget objekt",
    "Fetch data each time map view changes.": "Hent data hver gang kartvisningen endres.",
    "Filter keys": "Filtrer nøkler",
    "Filter…": "Filtrer...",
    "Format": "Format",
    "From zoom": "Fra zoom",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Gå til \"{feature}\"",
    "Heatmap intensity property": "Varmekart intensitet-egenskap",
    "Heatmap radius": "Varmekart radius",
    "Help": "Hjelp",
    "Hide controls": "Skjul kontrollene",
    "Home": "Hjem",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Hvor mye polylinjene skal simplifiseres på hvert zoom-nivå (mer = bedre ytelse og mer sømløst, mindre = mer nøyaktig)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe export options": "Iframe export options",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Image with custom width (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Image: {{http://image.url.com}}",
    "Import": "Import",
    "Import data": "Import data",
    "Import in a new layer": "Import in a new layer",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Include full screen link?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "Latitude",
    "Layer": "Layer",
    "Layer properties": "Layer properties",
    "Licence": "Licence",
    "Limit bounds": "Limit bounds",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Link with text: [[http://example.com|text of the link]]",
    "Long credits": "Long credits",
    "Longitude": "Longitude",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Map has been saved!",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Merge lines",
    "More controls": "More controls",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "No licence has been set",
    "No results": "No results",
    "Only visible features will be downloaded.": "Only visible features will be downloaded.",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Optional. Same as color if not set.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Please be sure the licence is compliant with your use.": "Please be sure the licence is compliant with your use.",
    "Please choose a format": "Please choose a format",
    "Please enter the name of the property": "Please enter the name of the property",
    "Please enter the new name of this property": "Please enter the new name of this property",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.",
    "Problem in the response": "Problem in the response",
    "Problem in the response format": "Problem in the response format",
    "Properties imported:": "Properties imported:",
    "Property to use for sorting features": "Property to use for sorting features",
    "Provide an URL here": "Provide an URL here",
    "Proxy request": "Proxy request",
    "Remote data": "Remote data",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Rename this property on all the features",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "Save",
    "Save anyway": "Save anyway",
    "Save current edits": "Save current edits",
    "Save this center and zoom": "Save this center and zoom",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "See all",
    "See data layers": "See data layers",
    "See full screen": "See full screen",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Short URL",
    "Short credits": "Short credits",
    "Show/hide layer": "Show/hide layer",
    "Simple link: [[http://example.com]]": "Simple link: [[http://example.com]]",
    "Slideshow": "Slideshow",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Start a hole here": "Start a hole here",
    "Start editing": "Start editing",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Stop editing",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "TMS format",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Text formatting",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been set.": "The zoom and center have been set.",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "To zoom",
    "Toggle edit mode (Shift+Click)": "Toggle edit mode (Shift+Click)",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transform to lines",
    "Transform to polygon": "Transform to polygon",
    "Type of layer": "Type of layer",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Untitled layer",
    "Untitled map": "Untitled map",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Update permissions and editors",
    "Url": "Url",
    "Use current bounds": "Use current bounds",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "User content credits",
    "User interface options": "User interface options",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Where do we go from here?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "You have unsaved changes.": "You have unsaved changes.",
    "Zoom in": "Zoom in",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Zoom out",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Zoom to this feature",
    "Zoom to this place": "Zoom to this place",
    "attribution": "attribution",
    "by": "by",
    "display name": "display name",
    "height": "height",
    "licence": "licence",
    "max East": "max East",
    "max North": "max North",
    "max South": "max South",
    "max West": "max West",
    "max zoom": "max zoom",
    "min zoom": "min zoom",
    "next": "next",
    "previous": "previous",
    "width": "width",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Optional.": "Optional.",
    "Paste your data here": "Paste your data here",
    "Please save the map first": "Please save the map first",
    "Unable to locate you.": "Unable to locate you.",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier."
}
;
L.registerLocale("no", locale);
L.setLocale("no");